#include "board.h"

void board_delay_ms(uint32_t ms) {
  clock_cpu_delay_ms(ms);
}

void board_init_sd_pins(SDXC_Type *ptr) {
  init_sdxc_pins(ptr, false);
}

bool board_sd_detect_card(SDXC_Type *ptr) {
  GPIO_Type *gpio = BOARD_APP_SDCARD_CARD_DETECTION_GPIO;

  uint32_t pin_index = BOARD_APP_SDCARD_CARD_DETECTION_PIN_INDEX;
  uint32_t gpio_index = BOARD_APP_SDCARD_CARD_DETECTION_GPIO_INDEX;

  return ((gpio->DI[gpio_index].VALUE & (1UL << pin_index)) == 0U);
}

void board_sd_switch_pins_to_1v8(SDXC_Type *ptr) {
  /* This feature is not supported */
}

uint32_t board_sd_configure_clock(SDXC_Type *ptr, uint32_t freq) {
  uint32_t actual_freq = 0;

  do {
    if (ptr != HPM_SDXC1) {
        break;
    }

    clock_name_t sdxc_clk = (ptr == HPM_SDXC0) ? clock_sdxc0 : clock_sdxc1;
    sdxc_enable_inverse_clock(ptr, false); sdxc_enable_sd_clock(ptr, false);

    /* Configure the clock below 400KHz for the identification state */
    if (freq <= 400000UL) {
      clock_set_source_divider(sdxc_clk, clk_src_osc24m, 63);
    }

    /* configure the clock to 24MHz for the SDR12/Default speed */
    else if (freq <= 25000000UL) {
      clock_set_source_divider(sdxc_clk, clk_src_osc24m, 1);
    }

    /* Configure the clock to 50MHz for the SDR25/High speed/50MHz DDR/50MHz SDR */
    else if (freq <= 50000000UL) {
      clock_set_source_divider(sdxc_clk, clk_src_pll1_clk1, 8);
    }

    /* Configure the clock to 100MHz for the SDR50 */
    else if (freq <= 100000000UL) {
      clock_set_source_divider(sdxc_clk, clk_src_pll1_clk1, 4);
    }

    /* Configure the clock to 166MHz for SDR104/HS200/HS400  */
    else if (freq <= 208000000UL) {
      clock_set_source_divider(sdxc_clk, clk_src_pll2_clk0, 2);
    }

    /* For other unsupported clock ranges, configure the clock to 24MHz */
    else {
      clock_set_source_divider(sdxc_clk, clk_src_osc24m, 1);
    }

    sdxc_enable_inverse_clock(ptr, true);
    sdxc_enable_sd_clock(ptr, true); actual_freq = clock_get_frequency(sdxc_clk);
  } while (false);

  return actual_freq;
}
