#include "main.h"

/* OS Info */
OSInfoType OSInfo;

/* OS Heap */
static uint8_t OSHeap[CFG_CPU0_SDRAM_SIZE];

static const HeapRegion_t xHeapRegions[] = {
  {OSHeap, sizeof(OSHeap)},        {NULL, 0}
};

/* IDLE Hook */
void vApplicationIdleHook(void) {
  OSInfo.idle_hook++;
}

/* Tick Hook */
void vApplicationTickHook(void) {
  OSInfo.tick_hook++;
}

/* Malloc Failed Hook */
void vApplicationMallocFailedHook(void) {
  OSInfo.malloc_failed_hook++;
}

/* Daemon Task Startup Hook */
void vApplicationDaemonTaskStartupHook(void) {
  clock_update_core_clock();
  memset(&OSInfo, 0, sizeof(OSInfoType));
}

/* Check For Stack Overflow */
void vApplicationStackOverflowHook(TaskHandle_t xTask, char *pcTaskName) {
  OSInfo.check_for_stack_overflow++;
}

uint32_t TestVar = 0;

/* FirstTask */
static void FirstTask(void *param) {
  for (;;) {
    TestVar++;
    vTaskDelay(1000);
  }
}

/* MainFunction */
int main(void) {
  /* OTP Driver */
  const otp_driver_interface_t *opt_driver;

  ROM_API_TABLE_ROOT->otp_driver_if->init();
  opt_driver = ROM_API_TABLE_ROOT->otp_driver_if;

  /* 设置Image1偏移 */
  uint32_t img_info;
  img_info = opt_driver->read_from_ip(25);

  if (!img_info) {
    img_info = CFG_IMAGE1_OFFSET / 262144;
    opt_driver->program(25, &img_info, 1);
  }

  /* 设置MCU为816MHz */
  pllctl_init_int_pll_with_freq(HPM_PLLCTL, 0, 816000000);
  clock_set_source_divider(clock_cpu0, clk_src_pll0_clk0, 1);
  clock_set_source_divider(clock_cpu1, clk_src_pll0_clk0, 1);

  /* 启动CPU1和MCHTMR0 */
  sysctl_set_cpu1_entry(HPM_SYSCTL, CFG_CPU1_FLASH_START);
  clock_set_source_divider(clock_mchtmr0, clk_src_osc24m, 24);
  sysctl_release_cpu1(HPM_SYSCTL); clock_enable(clock_mchtmr0);

  /* 启动FreeRTOS永不返回 */
  TaskHandle_t task = NULL;

  vPortDefineHeapRegions(xHeapRegions);
  xTaskCreate(FirstTask, "FirstTask", 5120, NULL, configMAX_PRIORITIES - 1, &task); vTaskStartScheduler();
}
