#include "main.h"

/* OS Info */
OSInfoType OSInfo;

/* OS Heap */
static uint8_t OSHeap[CFG_CPU1_SDRAM_SIZE];

static const HeapRegion_t xHeapRegions[] = {
  {OSHeap, sizeof(OSHeap)},        {NULL, 0}
};

/* IDLE Hook */
void vApplicationIdleHook(void) {
  OSInfo.idle_hook++;
}

/* Tick Hook */
void vApplicationTickHook(void) {
  OSInfo.tick_hook++;
}

/* Malloc Failed Hook */
void vApplicationMallocFailedHook(void) {
  OSInfo.malloc_failed_hook++;
}

/* Daemon Task Startup Hook */
void vApplicationDaemonTaskStartupHook(void) {
  clock_update_core_clock();
  memset(&OSInfo, 0, sizeof(OSInfoType));
}

/* Check For Stack Overflow */
void vApplicationStackOverflowHook(TaskHandle_t xTask, char *pcTaskName) {
  OSInfo.check_for_stack_overflow++;
}

/* FirstTask */
static void FirstTask(void *param) {
  for (;;) {
    vTaskDelay(1000);
  }
}

/* MainFunction */
int main(void) {
  /* 外设分配 */
  clock_add_to_group(clock_mchtmr1, 1);
  clock_add_to_group(clock_watchdog1, 1);

  /* 启动MCHTMR1 */
  clock_set_source_divider(clock_mchtmr1, clk_src_osc24m, 24);
  clock_connect_group_to_cpu(1, 1); clock_enable(clock_mchtmr1);

  /* 启动FreeRTOS永不返回 */
  TaskHandle_t task = NULL;

  vPortDefineHeapRegions(xHeapRegions);
  xTaskCreate(FirstTask, "FirstTask", 5120, NULL, configMAX_PRIORITIES - 1, &task); vTaskStartScheduler();
}
