# 简介
```
基于先辑半导体HPM6750的固件工程.
```

# CPU0 RAM
```
ILM0: 256KB, 0x00000000 ~ 0x0003FFFF.
DLM0: 256KB, 0x00080000 ~ 0x000BFFFF.

SRAM0: 512KB, 0x01080000 ~ 0x010FFFFF.
SDRAM: 16384KB, 0x40000000 ~ 0x40FFFFFF.
```

# CPU1 RAM
```
ILM1: 256KB, 0x00000000 ~ 0x0003FFFF.
DLM1: 256KB, 0x00080000 ~ 0x000BFFFF.

SRAM1: 512KB, 0x01100000 ~ 0x0117FFFF.
SDRAM: 16384KB, 0x41000000 ~ 0x41FFFFFF.
```

# CPU0 Flash
```
FLASH1: 4090KB, 0x80003000 ~ 0x804017FF.
```

# CPU1 Flash
```
FLASH1: 4090KB, 0x80401800 ~ 0x807FFFFF.
```

# Image Flash
```
Image0: 8192KB, 0x80000000 ~ 0x807FFFFF.
Image1: 8192KB, 0x80800000 ~ 0x80FFFFFF.
```

# 外设资源分配
```
MCHTMR0: 驱动CPU0 FreeRTOS.
MCHTMR1: 驱动CPU1 FreeRTOS.

WDG0: 运行在CPU0, 超时复位HPM6750(10.001s).
WDG1: 运行在CPU1, 超时复位HPM6750(10.001s).
```

# Heap & Stack
```
CPU0和CPU1各自的堆和栈分别分配在各自的DLMx中.
```

# image_ver.cfg
```
该文件固定为2字节, 用于定义固件镜像版本(固件版本).
```

# build_image.py
```
将bin文件转换为HPM6750能直接运行的固件镜像.
运行python3 build_image.py, 将在Output目录下生成2个固件镜像(NorFlash为133MHz).
```

# COM软件版本
```
SDK: v0.13.1.
```

```
FreeRTOS: v10.4.6.
```

```
hpm_sdmmc: 原封不动来自于HPMicro官方SDK v0.13.1.
```

# CPU0的软件版本
```
```

# CPU1的软件版本
```
```

# Solution构建及烧录
```
1. Build
   在SES中, 点击Build-->Batch Build-->Batch Rebuild Solution.
   Build会重构CPU0和CPU1工程, 并同时生成各自的Debug和Release版本固件.
```

```
2. Image Build
   打开命令提示符, 并进入Solution根目录.
   运行python3 build_image.py, 将在Solution根目录/Output目录下生成2个固件镜像.
```

```
3. Programming
   打开J-Flash, 点击File-->Open project, 选择Solution根目录/HPM6750.jflash.
   打开固件镜像, Start address可选择0x80000000(Image0 Flash)或0x80800000(Image1 Flash).
```

# HPM6750的SDK参数修改
## HPM6750_Flash.icf
```
文件位置: COM/SDK/HPM6750_Flash.icf.
```

```
基于SES HPM6750 CPU Support Package默认的HPM6750_Flash.icf修改.
```

## HPM6750xVMx_MemoryMap.xml
```
文件位置:
         CPU0: CPU0/HPM6750xVMx_MemoryMap.xml.
         CPU1: CPU1/HPM6750xVMx_MemoryMap.xml.
```

```
基于SES HPM6750 CPU Support Package默认的HPM6750xVMx_MemoryMap.xml修改.
```

# HPM6750的运行参数修改
## Image1的地址偏移
```
代码位置: CPU0/main.c: int main(void).
```

```
HPM6750默认只使用Image0, 未使用Image1.
当使用上Image1时, 需要在OTP 25中写入Image1的地址偏移, 并且一旦写入, 无法修改.
```

## CPU0和CPU1的运行频率
```
代码位置: CPU0/main.c: int main(void).
```

```
HPM6750默认对PLL0CLK0进行2分频, 用作CPU0和CPU1的运行频率.

PLL0CLK0默认只作为CPU0和CPU1的时钟源. 因此, 为了使CPU0和CPU1运行在816MHz,
先修改PLL0CLK0频率为816MHz, 然后再将PLL0CLK0的分频系数设置为1, 使MCU工作在816MHz.
```

# FreeRTOS的源码移植修改
## HPMicro
```
目录位置: COM\FreeRTOS\portable\GCC\RISC-V\HPMicro.
```

```
HPMicro目录下除FreeRTOSConfig.h文件以外, 其余代码文件原封不动来自于HPMicro官方SDK.
```

## RISCV_JAL警告
```
文件位置: COM\FreeRTOS\portable\GCC\RISC-V\portASM.S.
```

```
将jal portasmHANDLE_INTERRUPT修改为call portasmHANDLE_INTERRUPT.
用来消除当portasmHANDLE_INTERRUPT被放入RAM执行时, SES发出的编译警告.
```

## R_RISCV_CALL警告
```
文件位置: COM\FreeRTOS\portable\GCC\RISC-V\portASM.S.
```

```
为xPortStartFirstTask和pxPortInitialiseStack添加.type \Name, function声明, 以消除编译警告.
```
