#!/usr/bin/python3
# -*- coding: UTF-8 -*-

import os
import hashlib
import pathlib

# Image目录
ImageDir = './Output'

# CPU0 Debug固件
CPU0DebugImage = './CPU0/Output/Debug/Exe/CPU0.bin'
# CPU1 Debug固件
CPU1DebugImage = './CPU1/Output/Debug/Exe/CPU1.bin'

# CPU0 Release固件
CPU0ReleaseImage = './CPU0/Output/Release/Exe/CPU0.bin'
# CPU1 Release固件
CPU1ReleaseImage = './CPU1/Output/Release/Exe/CPU1.bin'

# CPU0 Debug数据
DebugCPU0Data = None
# CPU0 Debug填充数据
DebugCPU0FillData = None

# CPU1 Debug数据
DebugCPU1Data = None
# CPU1 Debug填充数据
DebugCPU1FillData = None

# CPU0 Release数据
ReleaseCPU0Data = None
# CPU0 Release填充数据
ReleaseCPU0FillData = None

# CPU1 Release数据
ReleaseCPU1Data = None
# CPU1 Release填充数据
ReleaseCPU1FillData = None

# EXIP BLOB
def exip_blob(img):
    # 打开文件
    img_file = open(ImageDir + img, 'wb')

    # 写入0x400个0xFF
    img_file.write(0x400 * b'\xFF')

    # 关闭文件
    img_file.close()

# XPI FLASH配置选项
def xpiflash_cfg_opt(img):
    # 打开文件
    img_file = open(ImageDir + img, 'ab')

    # 写入Header
    img_file.write(b'\x01')
    img_file.write(b'\x00')
    img_file.write(b'\xF9')
    img_file.write(b'\xFC')

    # 写入Option0
    img_file.write(b'\x07')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入Option1
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入Option2
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入0x400 - 16个0xFF
    img_file.write((0x400 - 16) * b'\xFF')

    # 关闭文件
    img_file.close()

# FW BLOB
def fw_blob(img):
    # 打开文件
    img_file = open(ImageDir + img, 'ab')

    # 写入0x800个0xFF
    img_file.write(0x800 * b'\xFF')

    # 关闭文件
    img_file.close()

# 固件容器头
def fw_container_header(img):
    # 打开文件
    img_file = open(ImageDir + img, 'ab')

    # 写入tag: 镜像标记0xBF
    img_file.write(b'\xBF')

    # 写入version: 镜像格式版本0x10
    img_file.write(b'\x10')

    # 写入length: 固件头长度, 包含固件容器头, 固件信息表, 设备配置块和签名块
    img_file.write(b'\x10')
    img_file.write(b'\x01')

    # 写入flags
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入sw_version: 软件版本号, 定义了当前镜像的版本, 当存储介质中有多份镜像时, BootROM根据该字段来判断哪一份是较新的镜像
    ver_file = open('./image_ver.cfg', 'rb')
    ver_data = ver_file.read(2)
    img_file.write(ver_data)
    ver_file.close()

    # 写入fuse_version
    img_file.write(b'\x00')

    # 写入number_of_fw: 指定当前镜像里包含的固件数, 最多支持2份固件
    img_file.write(b'\x02')

    # 写入device_config_block_offset: 设备配置块相对于固件容器头的偏移, 设备配置块是可选的, 若当前镜像中没有该块, 此字段须为0
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入signature_block_offser: 签名块相对于容器头的偏移, 若签名块不存在, 此字段须为0
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 关闭文件
    img_file.close()

# 固件信息表
def fw_info_table(img, ver):
    global DebugCPU0Data, ReleaseCPU0Data
    global DebugCPU0FillData, ReleaseCPU0FillData

    global DebugCPU1Data, ReleaseCPU1Data
    global DebugCPU1FillData, ReleaseCPU1FillData

    # 打开文件
    img_file = open(ImageDir + img, 'ab')

    # 写入offset: 固件相对于固件容器头的偏移
    #             HPM6750的SES工程默认的Flash代码起始地址为0x80003000, 即偏移为0x3000 = 0x1000(固件容器头起始位置) + 0x2000
    img_file.write(b'\x00')
    img_file.write(b'\x20')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入size: 固件的大小
    if ver == 0: # Debug
        img_file.write(os.path.getsize(CPU0DebugImage).to_bytes(4, 'little'))
    else: # Release
        img_file.write(os.path.getsize(CPU0ReleaseImage).to_bytes(4, 'little'))

    # 写入flags: 包含的标记有固件类型, CPU ID号, 哈希类型, 是否加密
    img_file.write(b'\x00') # core_id: CPU0
    img_file.write(b'\x01') # 固件哈希类型: SHA256
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入reserved
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入load_addr
    img_file.write(b'\x00')
    img_file.write(b'\x30')
    img_file.write(b'\x00')
    img_file.write(b'\x80')

    # 写入reserved
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入entry_point
    img_file.write(b'\x00')
    img_file.write(b'\x30')
    img_file.write(b'\x00')
    img_file.write(b'\x80')

    # 写入reserved
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入hash: 固件哈希值, 目前只使用32字节
    fw_data = b''

    if ver == 0: # Debug
        # 读取CPU0数据
        fw_file = open(CPU0DebugImage, 'rb')
        DebugCPU0Data = fw_file.read()
        fw_file.close()
        # 组合Debug固件数据
        fw_data += DebugCPU0Data
        # 填充CPU0数据
        DebugCPU0FillData = (4090 * 1024 - os.path.getsize(CPU0DebugImage)) * b'\xFF'
    else: # Release
        # 读取CPU0数据
        fw_file = open(CPU0ReleaseImage, 'rb')
        ReleaseCPU0Data = fw_file.read()
        fw_file.close()
        # 组合Release固件数据
        fw_data += ReleaseCPU0Data
        # 填充CPU0数据
        ReleaseCPU0FillData = (4090 * 1024 - os.path.getsize(CPU0ReleaseImage)) * b'\xFF'

    sha256 = hashlib.sha256()
    sha256.update(fw_data)
    img_file.write(sha256.digest())

    img_file.write(32 * b'\xFF')

    # 写入reserved
    img_file.write(32 * b'\xFF')

    # 写入offset: 固件相对于固件容器头的偏移
    #             HPM6750的SES工程默认的Flash代码起始地址为0x80401800, 即偏移为0x401800 = 0x1000(固件容器头起始位置) + 0x400800
    img_file.write(b'\x00')
    img_file.write(b'\x08')
    img_file.write(b'\x40')
    img_file.write(b'\x00')

    # 写入size: 固件的大小
    if ver == 0: # Debug
        img_file.write(os.path.getsize(CPU1DebugImage).to_bytes(4, 'little'))
    else: # Release
        img_file.write(os.path.getsize(CPU1ReleaseImage).to_bytes(4, 'little'))

    # 写入flags: 包含的标记有固件类型, CPU ID号, 哈希类型, 是否加密
    img_file.write(b'\x10') # core_id: CPU1
    img_file.write(b'\x01') # 固件哈希类型: SHA256
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入reserved
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入load_addr
    img_file.write(b'\x00')
    img_file.write(b'\x18')
    img_file.write(b'\x40')
    img_file.write(b'\x80')

    # 写入reserved
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入entry_point
    img_file.write(b'\x00')
    img_file.write(b'\x18')
    img_file.write(b'\x40')
    img_file.write(b'\x80')

    # 写入reserved
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')
    img_file.write(b'\x00')

    # 写入hash: 固件哈希值, 目前只使用32字节
    fw_data = b''

    if ver == 0: # Debug
        # 读取CPU1数据
        fw_file = open(CPU1DebugImage, 'rb')
        DebugCPU1Data = fw_file.read()
        fw_file.close()
        # 组合Debug固件数据
        fw_data += DebugCPU1Data
        # 填充CPU1数据
        DebugCPU1FillData = (4090 * 1024 - os.path.getsize(CPU1DebugImage)) * b'\xFF'
    else: # Release
        # 读CPU1固件
        fw_file = open(CPU1ReleaseImage, 'rb')
        ReleaseCPU1Data = fw_file.read()
        fw_file.close()
        # 组合Release固件数据
        fw_data += ReleaseCPU1Data
        # 填充CPU1固件
        ReleaseCPU1FillData = (4090 * 1024 - os.path.getsize(CPU1ReleaseImage)) * b'\xFF'

    sha256 = hashlib.sha256()
    sha256.update(fw_data)
    img_file.write(sha256.digest())

    img_file.write(32 * b'\xFF')

    # 写入reserved
    img_file.write(32 * b'\xFF')

    # 填充0xFF到固件起始地址处
    img_file.write((0x2000 - 16 - 128 - 128) * b'\xFF')

    # 关闭文件
    img_file.close()

# 填充固件文件到镜像
def fill_fw_to_image(img, ver):
    # 打开文件
    img_file = open(ImageDir + img, 'ab')

    # 填充固件文件
    fw_data = b''

    if ver == 0: # Debug
        fw_data += DebugCPU0Data + DebugCPU0FillData + DebugCPU1Data + DebugCPU1FillData
    elif ver == 1: # Release
        # 读BTL固件
        fw_data += ReleaseCPU0Data + ReleaseCPU0FillData + ReleaseCPU1Data + ReleaseCPU1FillData

    # 写入镜像文件
    img_file.write(fw_data)
    img_file.close()

# 生成Debug和Release镜像
def gen_debug_release_image():
    # 镜像文件
    debug_image = '/debug_image.bin'
    release_image = '/release_image.bin'

    # 生成Debug镜像
    exip_blob(debug_image)
    xpiflash_cfg_opt(debug_image)

    fw_blob(debug_image)
    fw_container_header(debug_image)

    fw_info_table(debug_image, 0)
    fill_fw_to_image(debug_image, 0)

    # 生成Release镜像
    exip_blob(release_image)
    xpiflash_cfg_opt(release_image)

    fw_blob(release_image)
    fw_container_header(release_image)

    fw_info_table(release_image, 1)
    fill_fw_to_image(release_image, 1)

def main():
    # 校验和
    checksum = 0

    # 创建镜像目录
    img_dir = pathlib.Path(ImageDir)

    if not img_dir.is_dir():
        os.mkdir(ImageDir)

    # 检测固件文件是否存在
    cpu0_debug_image = pathlib.Path(CPU0DebugImage)
    cpu1_debug_image = pathlib.Path(CPU1DebugImage)

    cpu0_release_image = pathlib.Path(CPU0ReleaseImage)
    cpu1_release_image = pathlib.Path(CPU1ReleaseImage)

    if cpu0_debug_image.is_file():
        checksum += 1
    else:
        print('CPU0DebugImage: ' + CPU0DebugImage + '不存在!')

    if cpu1_debug_image.is_file():
        checksum += 1
    else:
        print('CPU1DebugImage: ' + CPU1DebugImage + '不存在!')

    if cpu0_release_image.is_file():
        checksum += 1
    else:
        print('CPU0ReleaseImage: ' + CPU0ReleaseImage + '不存在!')

    if cpu1_release_image.is_file():
        checksum += 1
    else:
        print('CPU1ReleaseImage: ' + CPU1ReleaseImage + '不存在!')

    # 开始生成启动镜像
    if checksum == 4:
        gen_debug_release_image()

if __name__ == '__main__':
    main()
